You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by na...@apache.org on 2006/12/22 07:35:37 UTC

svn commit: r489565 [2/2] - in /webservices/axis/trunk/c/src/wsdl/org/apache/axis/wsdl: symbolTable/ wsdl2ws/ wsdl2ws/c/ wsdl2ws/c/literal/ wsdl2ws/cpp/ wsdl2ws/cpp/literal/ wsdl2ws/info/

Modified: webservices/axis/trunk/c/src/wsdl/org/apache/axis/wsdl/wsdl2ws/info/Type.java
URL: http://svn.apache.org/viewvc/webservices/axis/trunk/c/src/wsdl/org/apache/axis/wsdl/wsdl2ws/info/Type.java?view=diff&rev=489565&r1=489564&r2=489565
==============================================================================
--- webservices/axis/trunk/c/src/wsdl/org/apache/axis/wsdl/wsdl2ws/info/Type.java (original)
+++ webservices/axis/trunk/c/src/wsdl/org/apache/axis/wsdl/wsdl2ws/info/Type.java Thu Dec 21 22:35:36 2006
@@ -106,12 +106,10 @@
     /* Should this type be generated or not - by default, set to true except for anonymous types */
     private boolean externalize = true;
 
-    // vvv FJP - 17667
-    private boolean	restriction = false;
-    private String  restrictionBase = null;
-    private Vector  restrictionPattern = null;
-    private Vector  restrictionEnumeration = null;
-    // ^^^ FJP - 17667
+    private boolean	  restriction = false;
+    private String    restrictionBaseType = null;
+    private Vector    restrictionPattern = null;      // future - not currently used 
+    private Vector    restrictionEnumeration = null;  // future - not currently used
     
     /* Is anonymous type? qname.localname is checked, and if starts with '>', then true */
     private boolean isAnonymous = false;
@@ -339,18 +337,8 @@
      */
     public void setRestrictiondata(Vector vector)
     {
-        if (vector != null)
-        {
-            isSimpleType = true;
-            TypeEntry basetype = (TypeEntry) vector.firstElement();
-            if (basetype != null)
-            {
-                setBaseType(basetype.getQName());
-                String class4qname = CUtils.getclass4qname(baseType);
-                CUtils.addSchemaDefinedSimpleType(name, class4qname);
-            }
-            enumerationdata = vector;
-        }
+        isSimpleType = true;
+        enumerationdata = vector;
     }
 
     /* (non-Javadoc)
@@ -360,13 +348,14 @@
     {
         String str = "---------" + this.name + "------------\n";
         str = str + "languageSpecificName = " + languageSpecificName + "\n";
-        str = str + "isAnonymous =" + isAnonymous + "\n";
-        str = str + "isSimpleType =" + isSimpleType + "\n";
-        str = str + "externalize =" + externalize + "\n";
-        str = str + "isArray =" + isArray + "\n";
-        str = str + "baseType = " + baseType + "\n";
-        str = str + "restriction = " + restriction + "\n";
-        
+        str = str + "isAnonymous ="           + isAnonymous + "\n";
+        str = str + "isSimpleType ="          + isSimpleType + "\n";
+        str = str + "externalize ="           + externalize + "\n";
+        str = str + "isArray ="               + isArray + "\n";
+        str = str + "baseType = "             + baseType + "\n";
+        str = str + "restriction = "          + restriction + "\n";
+        str = str + "restrictionBaseType ="   + restrictionBaseType + "\n";
+         
         if (enumerationdata != null)
         {
             str = str + "enumerationType = " + ((TypeEntry) enumerationdata.get(0)).getQName() + "\n(";
@@ -508,6 +497,7 @@
     public void externalize(QName newQName)
     {           
         externalize(true);
+        
         setName(newQName);
         setLanguageSpecificName(newQName.getLocalPart());
     }     
@@ -530,18 +520,18 @@
     }    
     // vvv FJP - 17667
     /**
      * @return Returns the restrictionBase.
      */
-    public String getRestrictionBase()
+    public String getRestrictionBaseType()
     {
-        return restrictionBase;
+        return restrictionBaseType;
     }
     /**
      * @param restrictionBase The restrictionBase to set.
      */
-    public void setRestrictionBase(String restrictionBase)
+    public void setRestrictionBaseType(String restrictionBaseType)
     {
-        this.restrictionBase = restrictionBase;
+        this.restrictionBaseType = restrictionBaseType;
     }
     /**
      * @return Returns the restrictionEnumeration.



---------------------------------------------------------------------
@@ -530,18 +520,18 @@
     // vvv FJP - 17667
     /**
-     * @return Returns the restrictionBase.
+     * @return Returns the restrictionBaseType.
      */
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org